@@ -36,7 +36,9 @@
 #define FF_WM_PRETTY_ICEWM "IceWM"
 #define FF_WM_PRETTY_SPECTRWM "spectrwm"
 #define FF_WM_PRETTY_DTWM "dtwm"
-
+#define FF_WM_PRETTY_FVWM "fvwm"
+#define FF_WM_PRETTY_CTWM "ctwm"
+#define FF_WM_PRETTY_RATPOISON "ratpoison"
 
 #define FF_WM_PROTOCOL_TTY "TTY"
 #define FF_WM_PROTOCOL_X11 "X11"
