@@ -49,7 +49,7 @@ int main(void)
         &options->colors,
     };
 
-    for (size_t i = 0; i < sizeof(modules) / sizeof(modules[0]); i++)
+    for (size_t i = 0; i < ARRAY_SIZE(modules); i++)
         ((const FFModuleBaseInfo*) modules[i])->printModule(modules[i]);
 
     ffFinish();
